@@ -26,9 +26,11 @@ from .series import Series
 from modin.utils import to_pandas
 from modin.core.storage_formats.base.query_compiler import BaseQueryCompiler
 from modin.utils import _inherit_docstrings
+from modin.logging import logger_decorator
 
 
 @_inherit_docstrings(pandas.isna, apilink="pandas.isna")
+@logger_decorator("PANDAS-API", "isna", "info")
 def isna(obj):  # noqa: PR01, RT01, D200
     """
     Detect missing values for an array-like object.
@@ -43,6 +45,7 @@ isnull = isna
 
 
 @_inherit_docstrings(pandas.notna, apilink="pandas.notna")
+@logger_decorator("PANDAS-API", "notna", "info")
 def notna(obj):  # noqa: PR01, RT01, D200
     """
     Detect non-missing values for an array-like object.
@@ -57,6 +60,7 @@ notnull = notna
 
 
 @_inherit_docstrings(pandas.merge, apilink="pandas.merge")
+@logger_decorator("PANDAS-API", "merge", "info")
 def merge(
     left,
     right,
@@ -103,6 +107,7 @@ def merge(
 
 
 @_inherit_docstrings(pandas.merge_ordered, apilink="pandas.merge_ordered")
+@logger_decorator("PANDAS-API", "merge_ordered", "info")
 def merge_ordered(
     left,
     right,
@@ -142,6 +147,7 @@ def merge_ordered(
 
 
 @_inherit_docstrings(pandas.merge_asof, apilink="pandas.merge_asof")
+@logger_decorator("PANDAS-API", "merge_asof", "info")
 def merge_asof(
     left,
     right,
@@ -188,6 +194,11 @@ def merge_asof(
         or not isinstance(by, (str, type(None)))
         or not isinstance(left_by, (str, type(None)))
         or not isinstance(right_by, (str, type(None)))
+        # The implementation below assumes that the right index is unique
+        # because it uses merge_asof to map each position in the merged
+        # index to the label of the one right row that should be merged
+        # at that row position.
+        or not right.index.is_unique
     ):
         if isinstance(right, DataFrame):
             right = to_pandas(right)
@@ -308,6 +319,7 @@ def merge_asof(
 
 
 @_inherit_docstrings(pandas.pivot_table, apilink="pandas.pivot_table")
+@logger_decorator("PANDAS-API", "pivot_table", "info")
 def pivot_table(
     data,
     values=None,
@@ -343,6 +355,7 @@ def pivot_table(
 
 
 @_inherit_docstrings(pandas.pivot, apilink="pandas.pivot")
+@logger_decorator("PANDAS-API", "pivot", "info")
 def pivot(data, index=None, columns=None, values=None):  # noqa: PR01, RT01, D200
     """
     Return reshaped DataFrame organized by given index / column values.
@@ -353,6 +366,7 @@ def pivot(data, index=None, columns=None, values=None):  # noqa: PR01, RT01, D20
 
 
 @_inherit_docstrings(pandas.to_numeric, apilink="pandas.to_numeric")
+@logger_decorator("PANDAS-API", "to_numeric", "info")
 def to_numeric(arg, errors="raise", downcast=None):  # noqa: PR01, RT01, D200
     """
     Convert argument to a numeric type.
@@ -363,6 +377,7 @@ def to_numeric(arg, errors="raise", downcast=None):  # noqa: PR01, RT01, D200
 
 
 @_inherit_docstrings(pandas.unique, apilink="pandas.unique")
+@logger_decorator("PANDAS-API", "unique", "info")
 def unique(values):  # noqa: PR01, RT01, D200
     """
     Return unique values based on a hash table.
@@ -370,12 +385,33 @@ def unique(values):  # noqa: PR01, RT01, D200
     return Series(values).unique()
 
 
-@_inherit_docstrings(pandas.value_counts, apilink="pandas.value_counts")
+# Adding docstring since pandas docs don't have web section for this function.
+@logger_decorator("PANDAS-API", "value_counts", "info")
 def value_counts(
     values, sort=True, ascending=False, normalize=False, bins=None, dropna=True
-):  # noqa: PR01, RT01, D200
+):
     """
     Compute a histogram of the counts of non-null values.
+
+    Parameters
+    ----------
+    values : ndarray (1-d)
+        Values to perform computation.
+    sort : bool, default: True
+        Sort by values.
+    ascending : bool, default: False
+        Sort in ascending order.
+    normalize : bool, default: False
+        If True then compute a relative histogram.
+    bins : integer, optional
+        Rather than count values, group them into half-open bins,
+        convenience for pd.cut, only works with numeric data.
+    dropna : bool, default: True
+        Don't include counts of NaN.
+
+    Returns
+    -------
+    Series
     """
     return Series(values).value_counts(
         sort=sort,
@@ -387,6 +423,7 @@ def value_counts(
 
 
 @_inherit_docstrings(pandas.concat, apilink="pandas.concat")
+@logger_decorator("PANDAS-API", "concat", "info")
 def concat(
     objs: "Iterable[DataFrame | Series] | Mapping[Hashable, DataFrame | Series]",
     axis=0,
@@ -526,6 +563,7 @@ def concat(
 
 
 @_inherit_docstrings(pandas.to_datetime, apilink="pandas.to_datetime")
+@logger_decorator("PANDAS-API", "to_datetime", "info")
 def to_datetime(
     arg,
     errors="raise",
@@ -571,6 +609,7 @@ def to_datetime(
 
 
 @_inherit_docstrings(pandas.get_dummies, apilink="pandas.get_dummies")
+@logger_decorator("PANDAS-API", "get_dummies", "info")
 def get_dummies(
     data,
     prefix=None,
@@ -619,6 +658,7 @@ def get_dummies(
 
 
 @_inherit_docstrings(pandas.melt, apilink="pandas.melt")
+@logger_decorator("PANDAS-API", "melt", "info")
 def melt(
     frame,
     id_vars=None,
@@ -642,6 +682,7 @@ def melt(
 
 
 @_inherit_docstrings(pandas.crosstab, apilink="pandas.crosstab")
+@logger_decorator("PANDAS-API", "crosstab", "info")
 def crosstab(
     index,
     columns,
@@ -673,12 +714,31 @@ def crosstab(
     return DataFrame(pandas_crosstab)
 
 
-@_inherit_docstrings(pandas.lreshape, apilink="pandas.lreshape")
-def lreshape(
-    data: DataFrame, groups, dropna=True, label=None
-):  # noqa: PR01, RT01, D200
+# Adding docstring since pandas docs don't have web section for this function.
+@logger_decorator("PANDAS-API", "lreshape", "info")
+def lreshape(data: DataFrame, groups, dropna=True, label=None):
     """
-    Reshape wide-format data to long.
+    Reshape wide-format data to long. Generalized inverse of ``DataFrame.pivot``.
+
+    Accepts a dictionary, `groups`, in which each key is a new column name
+    and each value is a list of old column names that will be "melted" under
+    the new column name as part of the reshape.
+
+    Parameters
+    ----------
+    data : DataFrame
+        The wide-format DataFrame.
+    groups : dict
+        Dictionary in the form: `{new_name : list_of_columns}`.
+    dropna : bool, default: True
+        Whether include columns whose entries are all NaN or not.
+    label : optional
+        Deprecated parameter.
+
+    Returns
+    -------
+    DataFrame
+        Reshaped DataFrame.
     """
     if not isinstance(data, DataFrame):
         raise ValueError("can not lreshape with instance of type {}".format(type(data)))
@@ -689,6 +749,7 @@ def lreshape(
 
 
 @_inherit_docstrings(pandas.wide_to_long, apilink="pandas.wide_to_long")
+@logger_decorator("PANDAS-API", "wide_to_long", "info")
 def wide_to_long(
     df: DataFrame, stubnames, i, j, sep: str = "", suffix: str = r"\d+"
 ) -> DataFrame:  # noqa: PR01, RT01, D200
