@@ -36,6 +36,7 @@ from pandas.api.types import is_list_like, is_bool
 from pandas.core.dtypes.common import is_integer, is_bool_dtype, is_integer_dtype
 from pandas.core.indexing import IndexingError
 from modin.error_message import ErrorMessage
+from modin.logging import LoggerMetaClass, metaclass_resolver
 
 from .dataframe import DataFrame
 from .series import Series
@@ -267,7 +268,7 @@ def _compute_ndim(row_loc, col_loc):
     return ndim
 
 
-class _LocationIndexerBase(object):
+class _LocationIndexerBase(object, metaclass=LoggerMetaClass):
     """
     Base class for location indexer like loc and iloc.
 
@@ -424,23 +425,17 @@ class _LocationIndexerBase(object):
         # the target the user is trying to overwrite. This
         if isinstance(item, (pandas.Series, pandas.DataFrame, Series, DataFrame)):
             # convert indices in lookups to names, as Pandas reindex expects them to be so
+            axes_to_reindex = {}
             index_values = self.qc.index[row_lookup]
-            if not all(idx in item.index for idx in index_values):
-                raise ValueError(
-                    "Must have equal len keys and value when setting with "
-                    "an iterable"
-                )
+            if not index_values.equals(item.index):
+                axes_to_reindex["index"] = index_values
             if hasattr(item, "columns"):
                 column_values = self.qc.columns[col_lookup]
-                if not all(col in item.columns for col in column_values):
-                    # TODO: think if it is needed to handle cases when columns have duplicate names
-                    raise ValueError(
-                        "Must have equal len keys and value when setting "
-                        "with an iterable"
-                    )
-                item = item.reindex(index=index_values, columns=column_values)
-            else:
-                item = item.reindex(index=index_values)
+                if not column_values.equals(item.columns):
+                    axes_to_reindex["columns"] = column_values
+            # New value for columns/index make that reindex add NaN values
+            if axes_to_reindex:
+                item = item.reindex(**axes_to_reindex)
         try:
             item = np.array(item)
             if np.prod(to_shape) == np.prod(item.shape):
@@ -450,8 +445,8 @@ class _LocationIndexerBase(object):
         except ValueError:
             from_shape = np.array(item).shape
             raise ValueError(
-                "could not broadcast input array from shape {from_shape} into shape "
-                "{to_shape}".format(from_shape=from_shape, to_shape=to_shape)
+                f"could not broadcast input array from shape {from_shape} into shape "
+                + f"{to_shape}"
             )
 
     def _write_items(self, row_lookup, col_lookup, item):
@@ -598,7 +593,7 @@ class _LocationIndexerBase(object):
         return type(self)(masked_df)[(slice(None), col_loc)]
 
 
-class _LocIndexer(_LocationIndexerBase):
+class _LocIndexer(metaclass_resolver(_LocationIndexerBase)):
     """
     An indexer for modin_df.loc[] functionality.
 
@@ -851,7 +846,7 @@ class _LocIndexer(_LocationIndexerBase):
         return lookups
 
 
-class _iLocIndexer(_LocationIndexerBase):
+class _iLocIndexer(metaclass_resolver(_LocationIndexerBase)):
     """
     An indexer for modin_df.iloc[] functionality.
 
